==> customer-space-component-1.2.8-sources.jar: org/exoplatform/cs/integration.notification/NotificationUtils.java <==
/**
 * Copyright (C) 2015 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 **/
  
package org.exoplatform.cs.integration.notification;

import org.exoplatform.commons.api.notification.model.ArgumentLiteral;
import org.exoplatform.cs.dto.TicketDTO;
import java.util.Set;

public class NotificationUtils {
  public final static String CREATOR = "creator";
  public final static String OWNER = "owner";
  public static final ArgumentLiteral<Set> RECEIVERS = new ArgumentLiteral<Set>(Set.class, "receivers");
  public static final String TICKET_URL = "ticketUrl";
  public final static String DATE = "date";
  public final static String USER_NAME = "userName";
  public final static String ACTIVITY_ID = "activityId";
  public final static String TICKET_ID = "ticketId";
  public final static String TICKET_TITLE = "ticketTitle";
  public final static String TICKET_STATUS = "ticketStatus";
  public final static String ASSIGNEE = "assignee";
  public final static String OLD_VALUE = "oldValue";
  public final static String PERIOD = "period";

}

==> customer-space-component-1.2.16-sources.jar: org/exoplatform/cs/integration.notification/NotificationUtils.java <==
/**
 * Copyright (C) 2015 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 **/
  
package org.exoplatform.cs.integration.notification;

import org.exoplatform.commons.api.notification.model.ArgumentLiteral;
import org.exoplatform.cs.dto.TicketDTO;
import java.util.Set;

public class NotificationUtils {
  public final static String CREATOR = "creator";
  public final static String OWNER = "owner";
  public static final ArgumentLiteral<Set> RECEIVERS = new ArgumentLiteral<Set>(Set.class, "receivers");
  public static final String TICKET_URL = "ticketUrl";
  public final static String DATE = "date";
  public final static String USER_NAME = "userName";
  public final static String ACTIVITY_ID = "activityId";
  public final static String TICKET_ID = "ticketId";
  public final static String TICKET_TITLE = "ticketTitle";
  public final static String TICKET_STATUS = "ticketStatus";
  public final static String ASSIGNEE = "assignee";
  public final static String OLD_VALUE = "oldValue";
  public final static String PERIOD = "period";

  public static final String SPACE_URL = "spaceUrl";
  public final static String SPACE_ID = "spaceId";
  public final static String SPACE_NAME = "spaceTitle";
  public final static String END_DATE = "endDate";

}
